@@ -322,7 +322,7 @@ class ExcelInterface(COMInterface):
         return self.excel
 
     # ===== setup =====
-    def _setup_before_parallel(self) -> None:
+    def _setup_before_parallel(self, scheduler_address=None) -> None:
         # メインプロセスで、並列プロセスを開始する前に行う前処理
 
         related_files = [self._original_input_xlsm_path]
@@ -345,7 +345,7 @@ class ExcelInterface(COMInterface):
         related_files.extend(self._original_related_file_paths)
 
         # dask worker 向け
-        self._distribute_files(related_files)
+        self._distribute_files(related_files, scheduler_address)
 
     def _re_register_paths(self, suffix):
         # self.hoge_path を dask worker space のファイルに変える
@@ -381,7 +381,7 @@ class ExcelInterface(COMInterface):
         CoInitialize()
 
         # 元のファイルを保護するため space のファイルを使用
-        suffix = self._get_worker_index_from_optimizer(opt)
+        suffix = self._get_file_suffix(opt)
         self._re_register_paths(suffix)
 
         # excel に繋ぐ
@@ -505,8 +505,10 @@ class ExcelInterface(COMInterface):
         if not os.path.exists(xla_file_path):
             raise FileNotFoundError(
                 _(
-                    en_message='Femtet XLA file not found: {xla_file_path}',
-                    jp_message='Femtet XLA ファイルが見つかりません: {xla_file_path}',
+                    en_message='Femtet XLA file ({xla_file_path}) not found. '
+                               'Please run `Enable Macros` command.',
+                    jp_message='Femtet XLA ファイル ({xla_file_path}) が見つかりません。'
+                               '「マクロ機能の有効化」を実行してください。',
                     xla_file_path=xla_file_path
                 )
             )
